@@ -137,7 +137,7 @@ use warnings;
 
 use base qw{ Astro::Coord::ECI::TLE };
 
-our $VERSION = '0.101';
+our $VERSION = '0.102';
 
 use Astro::Coord::ECI::Utils 0.091 qw{:all};
 use Carp;
@@ -432,7 +432,7 @@ is also taken into account for the non-specular flares.
 
 Atmospheric extinction is calculated according to the article by Daniel
 W.  Green in the July 1992 issue of "International Comet Quarterly", and
-available at L<http://www.cfa.harvard.edu/icq/ICQExtinct.html>. Because
+available at L<http://www.icq.eps.harvard.edu/ICQExtinct.html>. Because
 Heavens Above does not display flares dimmer than a certain magnitude
 (-6 for day flares, and apparently 0 for night flares), it may not
 display a flare that this code predicts. I have no information how
@@ -1681,7 +1681,7 @@ sub _set_operational_status {
 # All Iridium Classic satellites.
 #
 # Generated by Astro::SpaceTrack tools/all_iridium_classic -tle -indent=0
-# on Fri Jul 20 13:07:17 2018 GMT
+# on Sun Jul 29 21:24:59 2018 GMT
 
 __PACKAGE__->status( clear => 'iridium' );
 __PACKAGE__->status( add => 24792, iridium => 'D', 'Iridium 8', 'Decayed 2017-11-24' );
@@ -1721,7 +1721,7 @@ __PACKAGE__->status( add => 24967, iridium => '-', 'Iridium 36', 'Tumbling' );
 __PACKAGE__->status( add => 24968, iridium => 'D', 'Iridium 37', 'Decayed 2018-05-26' );
 __PACKAGE__->status( add => 24969, iridium => 'D', 'Iridium 34', 'Decayed 2018-01-08' );
 __PACKAGE__->status( add => 25039, iridium => 'D', 'Iridium 43', 'Decayed 2018-02-11' );
-__PACKAGE__->status( add => 25040, iridium => '-', 'Iridium 41', 'Tumbling' );
+__PACKAGE__->status( add => 25040, iridium => 'D', 'Iridium 41', 'Decayed 2018-07-28' );
 __PACKAGE__->status( add => 25041, iridium => '-', 'Iridium 40', 'Tumbling' );
 __PACKAGE__->status( add => 25042, iridium => '-', 'Iridium 39', 'Tumbling' );
 __PACKAGE__->status( add => 25043, iridium => '-', 'Iridium 38', 'Tumbling' );
@@ -1780,13 +1780,13 @@ __PACKAGE__->status( add => 27374, iridium => 'D', 'Iridium 94', 'Decayed 2018-0
 __PACKAGE__->status( add => 27375, iridium => '+', 'Iridium 95', '' );
 __PACKAGE__->status( add => 27376, iridium => '-', 'Iridium 96', 'Tumbling' );
 __PACKAGE__->status( add => 27450, iridium => 'S', 'Iridium 97', '' );
-__PACKAGE__->status( add => 27451, iridium => 'S', 'Iridium 98', '' );
+__PACKAGE__->status( add => 27451, iridium => '-', 'Iridium 98', 'Tumbling' );
 
 # Summary:
 # Operational [+]: 17
-#       Spare [S]: 16
+#       Spare [S]: 15
 #    Tumbling [-]: 37
-#     Decayed [D]: 27
+#     Decayed [D]: 28
 
 1;
 
